==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/lens/WeightLens.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.lens;

import net.minecraft.class_1297;
import net.minecraft.class_1540;
import net.minecraft.class_1682;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1893;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2346;
import net.minecraft.class_2388;
import net.minecraft.class_239;
import net.minecraft.class_2398;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3965;
import org.jetbrains.annotations.Nullable;

import vazkii.botania.api.internal.ManaBurst;
import vazkii.botania.common.lib.BotaniaTags;
import vazkii.botania.xplat.BotaniaConfig;

public class WeightLens extends Lens {
	@Override
	public boolean collideBurst(ManaBurst burst, class_239 pos, boolean isManaBlock, boolean shouldKill, class_1799 stack) {
		class_1682 entity = burst.entity();
		if (!entity.field_6002.field_9236 && !burst.isFake() && pos.method_17783() == class_239.class_240.field_1332) {
			int harvestLevel = BotaniaConfig.common().harvestLevelWeight();

			class_3218 level = (class_3218) entity.field_6002;
			class_2338 bPos = ((class_3965) pos).method_17777();
			class_2680 state = level.method_8320(bPos);

			if (class_2346.method_10128(level.method_8320(bPos.method_10074()))
					&& state.method_26214(level, bPos) != -1
					&& level.method_8321(bPos) == null
					&& canSilkTouch(level, bPos, state, harvestLevel, entity.method_24921())) {
				class_1540 falling = class_1540.method_40005(level, bPos, state);
				falling.field_7192 = 1;
				level.method_14199(new class_2388(class_2398.field_11206, state), bPos.method_10263() + 0.5, bPos.method_10264() + 0.5, bPos.method_10260() + 0.5, 10, 0.45, 0.45, 0.45, 5);
			}
		}

		return shouldKill;
	}

	private static boolean canSilkTouch(class_3218 level, class_2338 pos, class_2680 state, int harvestLevel, @Nullable class_1297 owner) {
		if (state.method_26164(BotaniaTags.Blocks.WEIGHT_LENS_WHITELIST)) {
			return true;
		}
		class_1799 harvestToolStack = BoreLens.getHarvestToolStack(harvestLevel, state).method_7972();
		if (harvestToolStack.method_7960()) {
			return false;
		}
		harvestToolStack.method_7978(class_1893.field_9099, 1);

		class_1792 blockItem = state.method_26204().method_8389();
		for (var drop : class_2248.method_9609(state, level, pos, null, owner, harvestToolStack)) {
			if (drop.method_31574(blockItem)) {
				return true;
			}
		}
		return false;
	}
}

==> Botania-1.20.1-449-FABRIC-20250516.110607-19-sources.jar: vazkii/botania/common/item/lens/WeightLens.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.lens;

import net.minecraft.class_1297;
import net.minecraft.class_1540;
import net.minecraft.class_1682;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1893;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2346;
import net.minecraft.class_2388;
import net.minecraft.class_239;
import net.minecraft.class_2398;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3965;
import org.jetbrains.annotations.Nullable;

import vazkii.botania.api.internal.ManaBurst;
import vazkii.botania.common.lib.BotaniaTags;
import vazkii.botania.xplat.BotaniaConfig;

public class WeightLens extends Lens {
	@Override
	public boolean collideBurst(ManaBurst burst, class_239 pos, boolean isManaBlock, boolean shouldKill, class_1799 stack) {
		class_1682 entity = burst.entity();
		if (!entity.method_37908().field_9236 && !burst.isFake() && pos.method_17783() == class_239.class_240.field_1332) {
			int harvestLevel = BotaniaConfig.common().harvestLevelWeight();

			class_3218 level = (class_3218) entity.method_37908();
			class_2338 bPos = ((class_3965) pos).method_17777();
			class_2680 state = level.method_8320(bPos);

			if (class_2346.method_10128(level.method_8320(bPos.method_10074()))
					&& state.method_26214(level, bPos) != -1
					&& level.method_8321(bPos) == null
					&& canSilkTouch(level, bPos, state, harvestLevel, entity.method_24921())) {
				class_1540 falling = class_1540.method_40005(level, bPos, state);
				falling.field_7192 = 1;
				level.method_14199(new class_2388(class_2398.field_11206, state), bPos.method_10263() + 0.5, bPos.method_10264() + 0.5, bPos.method_10260() + 0.5, 10, 0.45, 0.45, 0.45, 5);
			}
		}

		return shouldKill;
	}

	private static boolean canSilkTouch(class_3218 level, class_2338 pos, class_2680 state, int harvestLevel, @Nullable class_1297 owner) {
		if (state.method_26164(BotaniaTags.Blocks.WEIGHT_LENS_WHITELIST)) {
			return true;
		}
		class_1799 harvestToolStack = BoreLens.getHarvestToolStack(harvestLevel, state).method_7972();
		if (harvestToolStack.method_7960()) {
			return false;
		}
		harvestToolStack.method_7978(class_1893.field_9099, 1);

		class_1792 blockItem = state.method_26204().method_8389();
		for (var drop : class_2248.method_9609(state, level, pos, null, owner, harvestToolStack)) {
			if (drop.method_31574(blockItem)) {
				return true;
			}
		}
		return false;
	}
}
